@@ -87,7 +87,8 @@ static bool is_local_var_matching(
         return true;
       }
     } else {
-      const zend_string* var_value_str = sp_zval_to_zend_string(var_value);
+      zend_string const* const var_value_str =
+          sp_zval_to_zend_string(var_value);
       bool match = sp_match_value(var_value_str, config_node->value,
                                   config_node->r_value);
 
@@ -327,7 +328,7 @@ static void should_disable(zend_execute_data* execute_data,
     }
 
     if (config_node->cidr) {
-      char* client_ip = getenv("REMOTE_ADDR");
+      const char* client_ip = get_ipaddr();
       if (client_ip && false == cidr_match(client_ip, config_node->cidr)) {
         goto next;
       }
@@ -357,7 +358,7 @@ static void should_disable(zend_execute_data* execute_data,
 #else
           execute_data->func->op_array.arg_info->is_variadic
 #endif
-						){
+      ) {
         sp_log_warn(
             "disable_function",
             "Snuffleupagus doesn't support variadic functions yet, sorry. "
@@ -573,13 +574,13 @@ ZEND_FUNCTION(eval_blacklist_callback) {
                      SP_TOKEN_EVAL_BLACKLIST);
     }
     if (config_eval->simulation) {
-      sp_log_msg("eval", SP_LOG_SIMULATION,
-                 "A call to %s was tried in eval, in %s:%d, logging it.",
-                 current_function_name, ZSTR_VAL(filename), line_number);
+      sp_log_simulation("eval",
+                        "A call to %s was tried in eval, in %s:%d, logging it.",
+                        current_function_name, ZSTR_VAL(filename), line_number);
     } else {
-      sp_log_msg("eval", SP_LOG_DROP,
-                 "A call to %s was tried in eval, in %s:%d, dropping it.",
-                 current_function_name, ZSTR_VAL(filename), line_number);
+      sp_log_drop("eval",
+                  "A call to %s was tried in eval, in %s:%d, dropping it.",
+                  current_function_name, ZSTR_VAL(filename), line_number);
     }
     efree(filename);
   }
